==> dde-shell_1.99.32.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>main</name>
    <message>
        <location filename="../package/main.qml" line="54"/>
        <source>WLAN on</source>
        <translation>WLAN włączony</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="55"/>
        <source>WLAN off</source>
        <translation>WLAN wyłączony</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="56"/>
        <source>Caps Lock on</source>
        <translation>Caps Lock włączony</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="57"/>
        <source>Caps Lock off</source>
        <translation>Caps Lock wyłączony</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="58"/>
        <source>Numeric keypad on</source>
        <translation>Klawiatura numeryczna włączona</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="59"/>
        <source>Numeric keypad off</source>
        <translation>Klawiatura numeryczna wyłączona</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="60"/>
        <source>Touchpad on</source>
        <translation>Touchpad włączony</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="61"/>
        <source>Touchpad off</source>
        <translation>Touchpad wyłączony</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="62"/>
        <source>Touchpad toggle</source>
        <translation>Przełącznik Touchpada</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="63"/>
        <source>Fn toggle</source>
        <translation>Przełącznik Fn</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="64"/>
        <source>Airplane mode on</source>
        <translation>Tryb samolotowy włączony</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="65"/>
        <source>Airplane mode off</source>
        <translation>Tryb samolotowy wyłączony</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="66"/>
        <source>Mute on</source>
        <translation>Wyciszenie włączone</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="67"/>
        <source>Mute off</source>
        <translation>Wyciszenie wyłączone</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="68"/>
        <source>Balanced power</source>
        <translation>Zasilanie zrównoważone</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="69"/>
        <source>Power saver</source>
        <translation>Oszczędność energii</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="70"/>
        <source>High performance</source>
        <translation>Wysoka wydajność</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="71"/>
        <source>Window effect enabled</source>
        <translation>Włączono efekty okna</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="72"/>
        <source>Window effect disabled</source>
        <translation>Wyłączono efekty okna</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="73"/>
        <source>Failed to enable window effects</source>
        <translation>Nie udało się włączyć niektórych efektów okna</translation>
    </message>
</context>
</TS>

==> dde-shell_1.99.34.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>main</name>
    <message>
        <location filename="../package/main.qml" line="54"/>
        <source>WLAN on</source>
        <translation>WLAN włączony</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="55"/>
        <source>WLAN off</source>
        <translation>WLAN wyłączony</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="56"/>
        <source>Caps Lock on</source>
        <translation>Caps Lock włączony</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="57"/>
        <source>Caps Lock off</source>
        <translation>Caps Lock wyłączony</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="58"/>
        <source>Numeric keypad on</source>
        <translation>Klawiatura numeryczna włączona</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="59"/>
        <source>Numeric keypad off</source>
        <translation>Klawiatura numeryczna wyłączona</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="60"/>
        <source>Touchpad on</source>
        <translation>Panel dotykowy włączony</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="61"/>
        <source>Touchpad off</source>
        <translation>Panel dotykowy wyłączony</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="62"/>
        <source>Touchpad toggle</source>
        <translation>Przełączanie panela dotykowego</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="63"/>
        <source>Fn toggle</source>
        <translation>Przełącznik Fn</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="64"/>
        <source>Airplane mode on</source>
        <translation>Tryb samolotowy włączony</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="65"/>
        <source>Airplane mode off</source>
        <translation>Tryb samolotowy wyłączony</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="66"/>
        <source>Mute on</source>
        <translation>Wyciszenie włączone</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="67"/>
        <source>Mute off</source>
        <translation>Wyciszenie wyłączone</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="68"/>
        <source>Balanced power</source>
        <translation>Zasilanie zrównoważone</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="69"/>
        <source>Power saver</source>
        <translation>Oszczędność energii</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="70"/>
        <source>High performance</source>
        <translation>Wysoka wydajność</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="71"/>
        <source>Window effect enabled</source>
        <translation>Włączono efekty okna</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="72"/>
        <source>Window effect disabled</source>
        <translation>Wyłączono efekty okna</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="73"/>
        <source>Failed to enable window effects</source>
        <translation>Nie udało się włączyć niektórych efektów okna</translation>
    </message>
</context>
</TS>
